<?php
/**
 * A quantidade informada em Efetivos deve ser maior ou igual a zero. */
namespace Planejamento\Logic\Efetivos\Exception;

class QuantidadeInformada extends \Planejamento\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $code = 0, \Exception $previous = null)
    {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }


    /**
     * Quantidade de comensais de cliente é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeInformadaClientes()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_informada_cliente"));
    }


    /**
     * Quantidade de comensais de funcionario é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeInformadaFuncionarios()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_informada_funcionario"));
    }


    /**
     * Quantidade de comensais de doacao é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeInformadaDoacoes()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_informada_doacao"));
    }


    /**
     * Quantidade de comensais efetivos é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeInformadaEfetivos()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_informada_efetivos"));
    }


    /**
     * Quantidade de comensais do prato é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeInformadaComensaisPrato()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_informada_prato"));
    }


    /**
     * Quantidade vendida por prato é menor que zero
     * @static
     * @throws QuantidadeInformada
     */
    public static function quantidadeVendidaInformadaPrato()
    {
        throw new self (tk_get_message_by_name("pla01000_qtd_vendida"));
    }

}
